@@ -130,7 +130,7 @@ def parse_configs_from_context(context, defaults):
             config = key_split[2]
             if service not in configs_dict:
                 configs_dict[service] = dict()
-            if defaults[service][config] == val:
+            if unicode(defaults[service][config]) == unicode(val):
                 continue
             configs_dict[service][config] = val
     return configs_dict
@@ -241,3 +241,20 @@ class ServiceParametersWorkflow(PatchedDynamicWorkflow):
             if (service in configs and
                     param.name in configs[service]):
                 param.initial_value = configs[service][param.name]
+
+
+class StatusFormatMixin(workflows.Workflow):
+    def __init__(self, request, context_seed, entry_point, *args, **kwargs):
+        super(StatusFormatMixin, self).__init__(request,
+                                                context_seed,
+                                                entry_point,
+                                                *args,
+                                                **kwargs)
+
+    def format_status_message(self, message):
+        error_description = getattr(self, 'error_description', None)
+
+        if error_description:
+            return error_description
+        else:
+            return message % self.context[self.name_property]
